@@ -10,7 +10,7 @@ no if $] > 5.017010, warnings => 'experimental::smartmatch';
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.25_05';
+our $VERSION = '0.25_06';
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
@@ -141,11 +141,12 @@ __END__
 
 =head1 NAME
 
-App::Midgen::Role::Output::Dist - A collection of output orientated methods used by L<App::Midgen>
+App::Midgen::Role::Output::Dist - Output Format - dist.ini,
+used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.25_05
+version: 0.25_06
 
 =head1 DESCRIPTION
 
